
#ifndef hal_cc2530znp_target_board_H
#define hal_cc2530znp_target_board_H

//Common msp430 includes
#include "msp430x22x4.h"

#include <stdarg.h>
//
//  METHODS REQUIRED FOR ZNP
//

extern void (*timerIsr)(void);


/**Initialize the Hardware Abstraction layer*/
void halInit();
/**Waits ms miliseconds*/
void delayMs(unsigned int ms);
/**Waits us microseconds*/
void delayUs(unsigned int us);
/**toggles the LED specified by led*/
signed int toggleLed(unsigned char led);
/**turns on the LED specified by led*/
signed int setLed(unsigned char led);
/**turns off all LEDs*/
void clearLeds();
/**Initializes the Vlo for timer use*/
signed int calibrateVlo();
/**Initializes TimerA. Seconds gives the time, when the overflow occures (max: 4)
 * wakeOnTimer can either be NO_WAKEUP or WAKEUP_AFTER_TIMER*/
signed int initTimer(unsigned char seconds, unsigned char wakeOnTimer);
/**Printf function to send characters on the UART to the PC*/
void tfp_printf(char *fmt, ...);
unsigned int convertAdcToLux(unsigned int adc);
void Init_Timer(void);
void handleTimer(void);

#define printf tfp_printf 

#define HAL_SLEEP()     ( __bis_SR_register(LPM3_bits + GIE))
#define HAL_WAKEUP()    ( __bic_SR_register_on_exit(LPM3_bits))

#define HAL_ENABLE_INTERRUPTS()         (_EINT())
#define HAL_DISABLE_INTERRUPTS()        (_DINT())

#define NO_WAKEUP                   0
#define WAKEUP_AFTER_TIMER          1
#define WAKEUP_AFTER_ACCELEROMETER  2
#define WAKEUP_AFTER_SRDY           4

//Macros for clock 
#define XTAL 8000000L
#define TICKS_PER_MS (XTAL / 1000 / 5 - 1)
#define TICKS_PER_US (TICKS_PER_MS / 1000)
#define VLO_NOMINAL 12000
#define VLO_MIN (VLO_NOMINAL - (VLO_NOMINAL/4)) //VLO min max = +/- 25% of nominal
#define VLO_MAX (VLO_NOMINAL + (VLO_NOMINAL/4))
#define GET_MCLK_FREQ()     8000000L    

//Required for Light Sensor 
#define LIGHT_SENSOR_ON()                  (P2OUT |= BIT1)  //ZNP Reset Line
#define LIGHT_SENSOR_OFF()                 (P2OUT &= ~BIT1)

#endif
